@@ -837,7 +837,7 @@ func TestSearchDashboards(t *testing.T) {
 	}
 
 	search := SearchQueryType("my dashboard")
-	filter := SearchFilterType(map[string][]string{"f__created_gt": []string{"1483639916"}})
+	filter := SearchFilterType(map[string][]string{"f__created_gt": {"1483639916"}})
 
 	t.Log("no search, no filter")
 	{
